@@ -12,7 +12,7 @@
 #' Calculate Cohen's D statistic for each effect in a gravity model object
 #'
 #' @author Jeffrey S. Evans  <jeffrey_evans@@tnc.org> and 
-#'         Melanie Murphy <melanie.murphy@@uwyo.edu>
+#'         Melanie A. Murphy <melanie.murphy@@uwyo.edu>
 #'
 #' @references
 #' Murphy M.A., R. Dezzani, D.S. Pilliod & A.S. Storfer (2010) Landscape genetics of 
@@ -35,22 +35,28 @@
 gravity.es <- function(x, actual.n = FALSE, alpha = 0.95) {
   if(!inherits(x, "gravity")) 
     stop(x, " is not a valid gravity model object")	
-  eff <- data.frame(t.value = summary(x$gravity)$tTable[,4], 
-                    df = summary(x$gravity)$fixDF$terms)
-    eff$cohen.d <- (2 * eff$t.value) / sqrt(eff$df)
-  eff <- eff[-1,]
-    eff <- data.frame(eff, p.value=round(summary(x$gravity)$tTable[,5],6)[-1]) 
 	cohen.ci <- function(d, n, conf.level = alpha) {
       deg.f = n + n - 2
-      #SD <- sqrt(((n + n)/(n * n) + 0.5 * es[,1][i] ^ 2 / deg.f) * 
-      #          ((n + n) / deg.f))
       SD <- sqrt(((n + n)/(n * n) + 0.5 * d ^ 2 / deg.f) * 
                 ((n + n) / deg.f))				
             Z <- -stats::qt((1 - alpha) / 2, deg.f)
           conf.int <- c(d - Z * SD, d + Z * SD)
 	    ci <- c(low.ci=conf.int[1], up.ci=conf.int[2])
       return(ci)
-    }	
+    }
+    if(x$constrained == TRUE) {	
+      eff <- data.frame(t.value = summary(x$gravity)$tTable[,4], 
+                        df = summary(x$gravity)$fixDF$terms)
+          eff$cohen.d <- (2 * eff$t.value) / sqrt(eff$df)
+        eff <- eff[-1,]
+      eff <- data.frame(eff, p.value=round(summary(x$gravity)$tTable[,5],6)[-1])
+    } else {
+      daf <- x$gravity$df.residual
+        tv <- stats::coef(summary(x$gravity))[,"t value"] 
+        p <- stats::coef(summary(x$gravity))[, "Pr(>|t|)"] 
+      eff <- data.frame(t.value = tv, df = daf)[-1,] 
+      eff <- data.frame(eff, p.value=round(p, 6)[-1]) 
+    }		
     ci <- list()	
 	  for(i in 1:nrow(eff)) {
 	    if(actual.n) N = length(x$y) else N = eff[,2][i] 
